yakumo.neutron.v2.vpn.service.Manager

Package yakumo :: Package neutron :: Package v2 :: Package vpn :: Module service :: Class Manager |
[hide private]
[frames] | no frames]

# Class Manager

source code

      object --+
               |
    base.Manager --+
                   |
                  Manager

Manager class for VPN services in Networking V2 API

Nested Classes | [hide private]
| resource_class Resource class for VPN services in Networking V2 API

Instance Methods | [hide private]
yakumo.neutron.v2.vpn.service.Resource |
create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, router=`'``__UNDEF__``'`, subnet=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) Create a VPN service | source code
Inherited from `base.Manager`: `__init__`, `find`, `find_one`, `get`, `get_empty`, `list` Inherited from `base.Manager` (private): `_attr2json`, `_find_gen`, `_json2attr`, `_no_such_api` Inherited from `object`: `__delattr__`, `__format__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__sizeof__`, `__str__`, `__subclasshook__`

Class Variables | [hide private]
| service_type = ``'``network``'``
| _attr_mapping = ``[``(``'``id``'``,` `'``id``'``,` <yakumo.mapper.NoopClass object `...``
| _json_resource_key = ``'``vpnservice``'``
| _json_resources_key = ``'``vpnservices``'``
| _url_resource_path = ``'``/v2.0/vpn/vpnservices``'``
Inherited from `base.Manager` (private): `_has_detail`, `_has_extra_attr`, `_hidden_methods`, `_id_attr`, `_update_method`, `_url_resource_list_path`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### create(self, name=`'``__UNDEF__``'`, description=`'``__UNDEF__``'`, router=`'``__UNDEF__``'`, subnet=`'``__UNDEF__``'`, project=`'``__UNDEF__``'`, is_enabled=`'``__UNDEF__``'`) | source code
Create a VPN service Parameters: `name` (str) - VPN name `description` (str) - Description `router` (yakumo.neutron.v2.router.Resource) - Router object `subnet` (yakumo.neutron.v2.subnet.Resource) - Subnet object `project` (yakumo.project.Resource) - Project object `is_enabled` (bool) - Whether the VPN service is enabled Returns: yakumo.neutron.v2.vpn.service.Resource Created VPN service Overrides: base.Manager.create

Class Variable Details | [hide private]

  ### _attr_mapping Value:
      [('id', 'id', mapper.Noop), ('name', 'name', mapper.Noop), ('descripti
      on', 'description', mapper.Noop), ('router', 'router_id', mapper.Resou
      rce('neutron.router')), ('subnet', 'subnet_id', mapper.Resource('neutr
      on.subnet')), ('project', 'tenant_id', mapper.Resource('project')), ('
      is_enabled', 'admin_state_up', mapper.Noop), ('status', 'status', mapp
      er.Noop),]